==> vala-0.0.9.tar.gz: vala-0.0.9/vala/valaenum.h <==
/* valaenum.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALAENUM_H__
#define __VALAENUM_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <vala/valadatatype.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_ENUM (vala_enum_get_type ())
#define VALA_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM, ValaEnum))
#define VALA_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM, ValaEnumClass))
#define VALA_IS_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM))
#define VALA_IS_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM))
#define VALA_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM, ValaEnumClass))

typedef struct _ValaEnumPrivate ValaEnumPrivate;

/**
 * Represents an enum declaration in the source code.
 */
struct _ValaEnum {
	ValaDataType parent;
	ValaEnumPrivate * priv;
};
struct _ValaEnumClass {
	ValaDataTypeClass parent;
};

ValaEnum* vala_enum_new (const char* _name, ValaSourceReference* source);
void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value);
char* vala_enum_get_cprefix (ValaEnum* self);
void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix);
void vala_enum_process_attributes (ValaEnum* self);
GType vala_enum_get_type ();

G_END_DECLS

#endif

==> vala-0.5.6.tar.gz: vala-0.5.6/vala/valaenum.h <==
/* valaenum.vala
 *
 * Copyright (C) 2006-2009  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAENUM_H__
#define __VALA_VALAENUM_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee/list.h>
#include <vala/valatypesymbol.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_ENUM (vala_enum_get_type ())
#define VALA_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM, ValaEnum))
#define VALA_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM, ValaEnumClass))
#define VALA_IS_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM))
#define VALA_IS_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM))
#define VALA_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM, ValaEnumClass))

typedef struct _ValaEnumPrivate ValaEnumPrivate;

/**
 * Represents an enum declaration in the source code.
 */
struct _ValaEnum {
	ValaTypeSymbol parent_instance;
	ValaEnumPrivate * priv;
};

struct _ValaEnumClass {
	ValaTypeSymbolClass parent_class;
};


ValaEnum* vala_enum_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference);
void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value);
void vala_enum_add_method (ValaEnum* self, ValaMethod* m);
GeeList* vala_enum_get_values (ValaEnum* self);
GeeList* vala_enum_get_methods (ValaEnum* self);
char* vala_enum_get_cprefix (ValaEnum* self);
void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix);
void vala_enum_process_attributes (ValaEnum* self);
void vala_enum_set_type_id (ValaEnum* self, const char* type_id);
gboolean vala_enum_get_is_flags (ValaEnum* self);
void vala_enum_set_is_flags (ValaEnum* self, gboolean value);
gboolean vala_enum_get_has_type_id (ValaEnum* self);
void vala_enum_set_has_type_id (ValaEnum* self, gboolean value);
GType vala_enum_get_type (void);


G_END_DECLS

#endif
